@@ -1,7 +1,9 @@
 /*
  * ProFTPD - FTP server daemon
- * Copyright (c) 1997, Public Flood Software
- *  
+ * Copyright (c) 1997, 1998 Public Flood Software
+ * Copyright (c) 1999, 2000 MacGyver aka Habeeb J. Dihu <macgyver@tos.net>
+ * Copyright (c) 2001, 2002, 2003 The ProFTPD Project team
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -14,16 +16,21 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ *
+ * As a special exemption, Public Flood Software/MacGyver aka Habeeb J. Dihu
+ * and other respective copyright holders give permission to link this program
+ * with OpenSSL, and distribute the resulting executable, without including
+ * the source code for OpenSSL in the source distribution.
  */
 
 /* FTP commands and responses (may not all be implemented)
  *
- * $Id: ftp.h,v 1.6 1997/10/29 18:51:26 flood Exp $
+ * $Id: ftp.h,v 1.10 2003/08/06 22:03:32 castaglia Exp $
  */
 
-#ifndef __FTP_H
-#define __FTP_H
+#ifndef PR_FTP_H
+#define PR_FTP_H
 
 /* Commands (minimum required supported level) */
 #define C_USER	"USER"		/* Specify a username */
@@ -37,7 +44,9 @@
 #define C_REIN	"REIN"		/* Reinitialize account information (not supported) */
 #define C_QUIT	"QUIT"		/* Close control connection and logout (if no transfer pending) */
 #define C_PORT	"PORT"		/* PORT h1,h2,h3,h4,p1,p2 (specify User address/port for data connection) */
+#define	C_EPRT	"EPRT"		/* Extended PORT */
 #define C_PASV	"PASV"		/* Next transfer data connection is from client to server */
+#define	C_EPSV	"EPSV"		/* Extended PASV */
 #define C_TYPE	"TYPE"		/* A = ASCII, E = EBCDIC, I = Image, L<byte size> = Local byte size */
 #define C_STRU	"STRU"		/* File structure (not implemented) */
 #define C_MODE	"MODE"		/* Transfer Mode (S - Stream, B - Block, C - Compressed (not supported) */
@@ -66,6 +75,20 @@
 #define C_STAT	"STAT"		/* Status */
 #define C_HELP	"HELP"		/* Help */
 #define C_NOOP	"NOOP"		/* Returns 200 and does nothing */
+#define C_FEAT	"FEAT"		/* Request list of server-supported features */
+#define C_OPTS	"OPTS"		/* Specify options for FTP commands */
+
+/* RFC2228 FTP Security commands */
+#define C_ADAT  "ADAT"		/* Authentication/security data */
+#define C_AUTH  "AUTH"		/* Authentication/security mechanism */
+#define C_CCC   "CCC"		/* Clear command channel */
+#define C_CONF  "CONF"		/* Confidentiality protected command */
+#define C_ENC   "ENC"		/* Privacy protected command */
+#define C_MIC   "MIC"		/* Integrity protected command */
+#define C_PBSZ  "PBSZ"		/* Protection buffer size */
+#define C_PROT  "PROT"		/* Data channel protection level */
+
+#define C_ANY	"*"		/* Special "wildcard" matching command */
 
 /* Command groupings */
 
@@ -92,15 +115,24 @@
 #define R_225	"225"		/* Data connection open; no transfer in progress */
 #define R_226	"226"		/* Closing data connection.  File transfer/abort successful */
 #define R_227	"227"		/* Entering passive mode (h1,h2,h3,h4,p1,p2) */
+#define	R_229	"229"		/* Entering extended passive mode (|||p|) */
 #define R_230	"230"		/* User logged in, proceed */
+#define R_232   "232"		/* User logged in, authorized by security data */
+#define R_234   "234"		/* Security data exchange complete */
+#define R_235   "235"		/* Security exchange successful */
+
 #define R_250	"250"		/* Requested file action okay, completed. */
 #define R_257	"257"		/* "PATHNAME" created. */
 #define R_331	"331"		/* User name okay, need password. */
 #define R_332	"332"		/* Need account for login. */
+#define R_334   "334"		/* Security data required */
+#define R_335   "335"		/* Additional security data required */
+#define R_336   "336"		/* Username OK, need password; presenting challenge */
 #define R_350	"350"		/* Requested file action pending further info */
 #define R_421	"421"		/* Service not available, closing control connection (service is about to be shutdown) */
 #define R_425	"425"		/* Can't open data connection */
 #define R_426	"426"		/* Connection closed; transfer aborted */
+#define R_431   "431"		/* Necessary security resource is unavailable */
 #define R_450	"450"		/* Requested file action not taken (file unavailable; busy) */
 #define R_451	"451"		/* Requested action aborted; local error in processing */
 #define R_452	"452"		/* Requested action not taken; insufficient storage space */
@@ -109,11 +141,22 @@
 #define R_502	"502"		/* Command not implemented */
 #define R_503	"503"		/* Bad sequence of commands */
 #define R_504	"504"		/* Command not implemented for that parameter */
+#define	R_522	"522"		/* Extended port failure: unknown network protocol */
 #define R_530	"530"		/* Not logged in */
 #define R_532	"532"		/* Need account for storing files */
+#define R_533   "533"		/* Integrity protected command required by policy */
+#define R_534   "534"		/* Unwilling to accept security arguments */
+#define R_535   "535"		/* Data failed security check */
+#define R_536   "536"		/* Unsupported data channel protection level */
+#define R_537   "537"		/* Unsupported command protection by security mechanism */
 #define R_550	"550"		/* Requested action not taken. No access, etc */
 #define R_551	"551"		/* Requested action not taken, page type unknown */
 #define R_552	"552"		/* Requested file action aborted, exceeding storage allocation */
 #define	R_553	"553"		/* Requested action not taken, file name not allowed */
+#define R_554   "554"           /* Requested action not taken, invalid REST parameter (RFC 1123) */
+#define R_631	"631"		/* Integrity protected response (RFC 2228) */
+#define R_632	"632"		/* Privacy protected response (RFC 2228) */
+#define R_633	"633"		/* Confidentiality protected response (RFC 2228) */
+#define R_DUP	NULL		/* Duplicate last numeric in ml response */
 
-#endif /* __FTP_H */
+#endif /* PR_FTP_H */
